# Tutorial

The HoloNote library is a valuable tool that provides users with a range of options to create, edit, and save annotated regions from HoloViews plots.

The tutorial will walk you through the basic functionality of the HoloNote library.

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Overview <00_Overview>
First Annotation <01_First_Annotation>
Multiple Annotations <02_Multiple_Annotations>
Styling of Annotations <03_Styling_of_Annotations>
Make an App <04_Make_an_App>
Watch Events <05_Watch_Events>

```
